'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var bundlerPluginCore = require('@sentry/bundler-plugin-core');
var uuid = require('uuid');
var webpack4 = require('webpack-4');

function webpackReleaseInjectionPlugin(injectionCode) {
  var pluginName = "sentry-webpack-release-injection-plugin";
  return {
    name: pluginName,
    webpack: function webpack(compiler) {
      var _compiler$webpack;

      if (compiler !== null && compiler !== void 0 && (_compiler$webpack = compiler.webpack) !== null && _compiler$webpack !== void 0 && _compiler$webpack.BannerPlugin) {
        compiler.options.plugins.push(new compiler.webpack.BannerPlugin({
          raw: true,
          include: /\.(js|ts|jsx|tsx|mjs|cjs)$/,
          banner: injectionCode
        }));
      } else {
        compiler.options.plugins.push( // eslint-disable-next-line @typescript-eslint/no-unsafe-argument, @typescript-eslint/no-unsafe-call
        new webpack4.BannerPlugin({
          raw: true,
          include: /\.(js|ts|jsx|tsx|mjs|cjs)$/,
          banner: injectionCode
        }));
      }
    }
  };
}

function webpackDebugIdInjectionPlugin() {
  var pluginName = "sentry-webpack-debug-id-injection-plugin";
  return {
    name: pluginName,
    webpack: function webpack(compiler) {
      var _compiler$webpack2;

      if (compiler !== null && compiler !== void 0 && (_compiler$webpack2 = compiler.webpack) !== null && _compiler$webpack2 !== void 0 && _compiler$webpack2.BannerPlugin) {
        compiler.options.plugins.push(new compiler.webpack.BannerPlugin({
          raw: true,
          include: /\.(js|ts|jsx|tsx|mjs|cjs)$/,
          banner: function banner() {
            return bundlerPluginCore.getDebugIdSnippet(uuid.v4());
          }
        }));
      } else {
        compiler.options.plugins.push( // eslint-disable-next-line @typescript-eslint/no-unsafe-argument, @typescript-eslint/no-unsafe-call
        new webpack4.BannerPlugin({
          raw: true,
          include: /\.(js|ts|jsx|tsx|mjs|cjs)$/,
          banner: function banner() {
            return bundlerPluginCore.getDebugIdSnippet(uuid.v4());
          }
        }));
      }
    }
  };
}

var sentryUnplugin = bundlerPluginCore.sentryUnpluginFactory({
  releaseInjectionPlugin: webpackReleaseInjectionPlugin,
  debugIdInjectionPlugin: webpackDebugIdInjectionPlugin
}); // eslint-disable-next-line @typescript-eslint/no-explicit-any

var sentryWebpackPlugin = sentryUnplugin.webpack;

Object.defineProperty(exports, 'sentryCliBinaryExists', {
  enumerable: true,
  get: function () { return bundlerPluginCore.sentryCliBinaryExists; }
});
exports.sentryWebpackPlugin = sentryWebpackPlugin;
//# sourceMappingURL=index.js.map
